======
rororo
======

.. image:: https://img.shields.io/travis/playpauseandstop/rororo/master.svg
    :target: https://travis-ci.org/playpauseandstop/rororo
    :alt: Travis CI

.. image:: https://img.shields.io/pypi/v/rororo.svg
    :target: https://warehouse.python.org/project/rororo/
    :alt: Latest Version

.. image:: https://img.shields.io/pypi/pyversions/rororo.svg
    :target: https://warehouse.python.org/project/rororo/
    :alt: Python versions

.. image:: https://img.shields.io/pypi/l/rororo.svg
    :target: https://github.com/playpauseandstop/rororo/blob/master/LICENSE
    :alt: BSD License

.. image:: https://coveralls.io/repos/playpauseandstop/rororo/badge.svg?branch=master&service=github
    :target: https://coveralls.io/github/playpauseandstop/rororo
    :alt: Coverage

.. image:: https://readthedocs.org/projects/rororo/badge/?version=latest
    :target: http://rororo.readthedocs.org/en/latest/
    :alt: Documentation

Collection of utilities, helpers, and principles for building Python backend
applications. Supports `aiohttp.web <http://aiohttp.readthedocs.org/>`_,
`Flask <http://flask.pocoo.org/>`_, and your web-framework.

* Works on Python 3.4+
* BSD licensed
* Latest documentation `on Read the Docs <http://rororo.readthedocs.org/>`_
* Source, issues, and pull requests `on GitHub
  <https://github.com/playpauseandstop/rororo>`_
* Install with ``pip install rororo``
* Usage examples available in `examples/
  <https://github.com/playpauseandstop/rororo/tree/master/examples>`_ directory
